pub struct EndpointConfiguration {
pub descriptor: Option<EndpointDescriptor>,
pub super_speed_companion: Option<SuperSpeedEndpointCompanionDescriptor>,
/* private fields */
}Expand description
Endpoint configuration given to [UsbFunction.ConfigureEndpoint].
Fields
descriptor: Option<EndpointDescriptor>super_speed_companion: Option<SuperSpeedEndpointCompanionDescriptor>Trait Implementations
Sourceimpl Clone for EndpointConfiguration
impl Clone for EndpointConfiguration
Sourcefn clone(&self) -> EndpointConfiguration
fn clone(&self) -> EndpointConfiguration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointConfiguration
impl Debug for EndpointConfiguration
Sourceimpl<D: ResourceDialect> Decode<EndpointConfiguration, D> for EndpointConfiguration
impl<D: ResourceDialect> Decode<EndpointConfiguration, D> for EndpointConfiguration
Sourceimpl Default for EndpointConfiguration
impl Default for EndpointConfiguration
Sourcefn default() -> EndpointConfiguration
fn default() -> EndpointConfiguration
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<EndpointConfiguration, D> for &EndpointConfiguration
impl<D: ResourceDialect> Encode<EndpointConfiguration, D> for &EndpointConfiguration
Sourceimpl PartialEq for EndpointConfiguration
impl PartialEq for EndpointConfiguration
Sourcefn eq(&self, other: &EndpointConfiguration) -> bool
fn eq(&self, other: &EndpointConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for EndpointConfiguration
impl StructuralPartialEq for EndpointConfiguration
Sourceimpl TypeMarker for EndpointConfiguration
impl TypeMarker for EndpointConfiguration
Sourcetype Owned = EndpointConfiguration
type Owned = EndpointConfiguration
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for EndpointConfiguration
impl ValueTypeMarker for EndpointConfiguration
Sourcetype Borrowed<'a> = &'a EndpointConfiguration
type Borrowed<'a> = &'a EndpointConfiguration
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for EndpointConfiguration
impl RefUnwindSafe for EndpointConfiguration
impl Send for EndpointConfiguration
impl Sync for EndpointConfiguration
impl Unpin for EndpointConfiguration
impl UnsafeUnpin for EndpointConfiguration
impl UnwindSafe for EndpointConfiguration