pub struct UsbFunctionInterfaceControlRequest {
pub setup: UsbSetup,
pub write: Vec<u8>,
}Fields
setup: UsbSetupwrite: Vec<u8>Trait Implementations
Sourceimpl Clone for UsbFunctionInterfaceControlRequest
impl Clone for UsbFunctionInterfaceControlRequest
Sourcefn clone(&self) -> UsbFunctionInterfaceControlRequest
fn clone(&self) -> UsbFunctionInterfaceControlRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<UsbFunctionInterfaceControlRequest, D> for UsbFunctionInterfaceControlRequest
impl<D: ResourceDialect> Decode<UsbFunctionInterfaceControlRequest, D> for UsbFunctionInterfaceControlRequest
Sourceimpl<D: ResourceDialect> Encode<UsbFunctionInterfaceControlRequest, D> for &UsbFunctionInterfaceControlRequest
impl<D: ResourceDialect> Encode<UsbFunctionInterfaceControlRequest, D> for &UsbFunctionInterfaceControlRequest
Sourceimpl<D: ResourceDialect, T0: Encode<UsbSetup, D>, T1: Encode<UnboundedVector<u8>, D>> Encode<UsbFunctionInterfaceControlRequest, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<UsbSetup, D>, T1: Encode<UnboundedVector<u8>, D>> Encode<UsbFunctionInterfaceControlRequest, D> for (T0, T1)
Sourceimpl PartialEq for UsbFunctionInterfaceControlRequest
impl PartialEq for UsbFunctionInterfaceControlRequest
Sourcefn eq(&self, other: &UsbFunctionInterfaceControlRequest) -> bool
fn eq(&self, other: &UsbFunctionInterfaceControlRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for UsbFunctionInterfaceControlRequest
impl StructuralPartialEq for UsbFunctionInterfaceControlRequest
Sourceimpl TypeMarker for UsbFunctionInterfaceControlRequest
impl TypeMarker for UsbFunctionInterfaceControlRequest
Sourcetype Owned = UsbFunctionInterfaceControlRequest
type Owned = UsbFunctionInterfaceControlRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbFunctionInterfaceControlRequest
impl ValueTypeMarker for UsbFunctionInterfaceControlRequest
Sourcetype Borrowed<'a> = &'a UsbFunctionInterfaceControlRequest
type Borrowed<'a> = &'a UsbFunctionInterfaceControlRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for UsbFunctionInterfaceControlRequest
impl RefUnwindSafe for UsbFunctionInterfaceControlRequest
impl Send for UsbFunctionInterfaceControlRequest
impl Sync for UsbFunctionInterfaceControlRequest
impl Unpin for UsbFunctionInterfaceControlRequest
impl UnsafeUnpin for UsbFunctionInterfaceControlRequest
impl UnwindSafe for UsbFunctionInterfaceControlRequest