pub struct UsbFunctionInterfaceSetConfiguredRequest {
pub configured: bool,
pub speed: UsbSpeed,
}Fields
configured: boolspeed: UsbSpeedTrait Implementations
Sourceimpl Clone for UsbFunctionInterfaceSetConfiguredRequest
impl Clone for UsbFunctionInterfaceSetConfiguredRequest
Sourcefn clone(&self) -> UsbFunctionInterfaceSetConfiguredRequest
fn clone(&self) -> UsbFunctionInterfaceSetConfiguredRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbFunctionInterfaceSetConfiguredRequest
Sourceimpl<D: ResourceDialect> Decode<UsbFunctionInterfaceSetConfiguredRequest, D> for UsbFunctionInterfaceSetConfiguredRequest
impl<D: ResourceDialect> Decode<UsbFunctionInterfaceSetConfiguredRequest, D> for UsbFunctionInterfaceSetConfiguredRequest
Sourceimpl<D: ResourceDialect> Encode<UsbFunctionInterfaceSetConfiguredRequest, D> for &UsbFunctionInterfaceSetConfiguredRequest
impl<D: ResourceDialect> Encode<UsbFunctionInterfaceSetConfiguredRequest, D> for &UsbFunctionInterfaceSetConfiguredRequest
Sourceimpl<D: ResourceDialect, T0: Encode<bool, D>, T1: Encode<UsbSpeed, D>> Encode<UsbFunctionInterfaceSetConfiguredRequest, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<bool, D>, T1: Encode<UsbSpeed, D>> Encode<UsbFunctionInterfaceSetConfiguredRequest, D> for (T0, T1)
impl Eq for UsbFunctionInterfaceSetConfiguredRequest
Sourceimpl Ord for UsbFunctionInterfaceSetConfiguredRequest
impl Ord for UsbFunctionInterfaceSetConfiguredRequest
Sourcefn cmp(&self, other: &UsbFunctionInterfaceSetConfiguredRequest) -> Ordering
fn cmp(&self, other: &UsbFunctionInterfaceSetConfiguredRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbFunctionInterfaceSetConfiguredRequest
impl PartialEq for UsbFunctionInterfaceSetConfiguredRequest
Sourcefn eq(&self, other: &UsbFunctionInterfaceSetConfiguredRequest) -> bool
fn eq(&self, other: &UsbFunctionInterfaceSetConfiguredRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbFunctionInterfaceSetConfiguredRequest
impl PartialOrd for UsbFunctionInterfaceSetConfiguredRequest
impl Persistable for UsbFunctionInterfaceSetConfiguredRequest
impl StructuralPartialEq for UsbFunctionInterfaceSetConfiguredRequest
Sourceimpl TypeMarker for UsbFunctionInterfaceSetConfiguredRequest
impl TypeMarker for UsbFunctionInterfaceSetConfiguredRequest
Sourcetype Owned = UsbFunctionInterfaceSetConfiguredRequest
type Owned = UsbFunctionInterfaceSetConfiguredRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbFunctionInterfaceSetConfiguredRequest
impl ValueTypeMarker for UsbFunctionInterfaceSetConfiguredRequest
Sourcetype Borrowed<'a> = &'a UsbFunctionInterfaceSetConfiguredRequest
type Borrowed<'a> = &'a UsbFunctionInterfaceSetConfiguredRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for UsbFunctionInterfaceSetConfiguredRequest
impl RefUnwindSafe for UsbFunctionInterfaceSetConfiguredRequest
impl Send for UsbFunctionInterfaceSetConfiguredRequest
impl Sync for UsbFunctionInterfaceSetConfiguredRequest
impl Unpin for UsbFunctionInterfaceSetConfiguredRequest
impl UnsafeUnpin for UsbFunctionInterfaceSetConfiguredRequest
impl UnwindSafe for UsbFunctionInterfaceSetConfiguredRequest